# wexample-prompt

CLI prompt utilities for Python applications with rich terminal output support.

## License

MIT License - See LICENSE file for details.

## Links

- [GitHub Repository](https://github.com/wexample/python-prompt)
- [Issues](https://github.com/wexample/python-prompt/issues)